@@ -157,8 +157,8 @@ class CliApplication():
         else:
             # print(response.json())
             data = response.json()
-            if data["error"]:
-                print(data["error"])
+            if data["result"]["error"]:
+                print(data["result"]["error"])
                 sys.exit()
             else:
                 return []
@@ -182,7 +182,7 @@ class CliApplication():
             try:
                 codefile.close()
                 data = response.json()
-                if data["code" == 100]:
+                if data["code"] == 100:
                     print(data["result"]["message"])
                 # print("Server error!", response.json())
             except ValueError:
